import doctest

import pytest


if __name__ == "__main__":
    doctest.testmod()
    pytest.main()
